#
# spec file for package maven-script-interpreter
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           maven-script-interpreter
Version:        1.6
Release:        1.2
Summary:        Maven Script Interpreter
License:        Apache-2.0
Group:          Development/Libraries/Java
URL:            https://maven.apache.org/shared/maven-script-interpreter/
Source0:        https://dlcdn.apache.org/maven/shared/%{name}-%{version}-source-release.zip
Source1:        %{name}-build.xml
BuildRequires:  ant
BuildRequires:  apache-commons-io
BuildRequires:  bsh2
BuildRequires:  fdupes
BuildRequires:  javapackages-local >= 6
BuildRequires:  slf4j
BuildRequires:  unzip
BuildArch:      noarch

%description
This component provides some utilities to interpret/execute some scripts for
various implementations: Groovy or BeanShell.

Groovy script is currently disabled.

%package javadoc
Summary:        Javadoc for %{name}
Group:          Documentation/HTML

%description javadoc
API documentation for %{name}.

%prep
%setup -q
cp %{SOURCE1} build.xml

%pom_remove_parent
%pom_xpath_inject pom:project "<groupId>org.apache.maven.shared</groupId>"

%pom_remove_dep :groovy
rm src/main/java/org/apache/maven/shared/scriptinterpreter/GroovyScriptInterpreter.java
rm src/test/java/org/apache/maven/shared/scriptinterpreter/GroovyScriptInterpreterTest.java
rm src/test/java/org/apache/maven/shared/scriptinterpreter/ScriptRunnerTest.java
sed -i /GroovyScriptInterpreter/d src/main/java/org/apache/maven/shared/scriptinterpreter/ScriptRunner.java

%build
mkdir -p lib
build-jar-repository -s lib \
	bsh2/bsh \
	commons-io \
    slf4j/api \
    slf4j/simple

%{ant} \
	jar javadoc

%install
# jar
install -dm 0755 %{buildroot}%{_javadir}/%{name}
install -pm 0644 target/%{name}-%{version}.jar %{buildroot}%{_javadir}/%{name}/%{name}.jar

# pom
install -dm 0755 %{buildroot}%{_mavenpomdir}/%{name}
%{mvn_install_pom} pom.xml %{buildroot}%{_mavenpomdir}/%{name}/%{name}.pom
%add_maven_depmap %{name}/%{name}.pom %{name}/%{name}.jar

# javadoc
install -dm 0755 %{buildroot}%{_javadocdir}/%{name}
cp -pr target/site/apidocs/* %{buildroot}%{_javadocdir}/%{name}/
%fdupes -s %{buildroot}%{_javadocdir}

%files -f .mfiles
%license LICENSE NOTICE
%doc DEPENDENCIES

%files javadoc
%{_javadocdir}/%{name}
%license LICENSE NOTICE

%changelog
* Fri Sep 27 2024 Fridrich Strba <fstrba@suse.com>
- Upgrade to version 1.6
  * Changes
    + [MSHARED-1001] Shared GitHub Actions
    + [MSHARED-1002] Require Java 8
    + [MSHARED-1068] Upgrade Groovy to 4.0.2
    + simplify exception management
    + [MSHARED-1368] - Synchronize interpreter execution
    + [MSHARED-1359] - Use child first classloader in
    BeanShellScriptInterpreter
    + [MSHARED-1359] - Optimize classloader in
    BeanShellScriptInterpreter
    + [MSHARED-1359] - Allow reuse the same classloader for multiple
    script executions
    + [MSHARED-1386] - Manage context ClassLoader for current thread
* Thu Apr 28 2022 Fridrich Strba <fstrba@suse.com>
- Upgrade to version 1.3
  * Improvement
    + [MSHARED-828] - Require Java 7
    + [MSHARED-879] - make build Reproducible
    + [MSHARED-906] - Add GitHub Action to confirm build PR
    + [MSHARED-907] - Output build log from script to maven mojo log
    + [MSHARED-910] - Redundant option failOnException
    + [MSHARED-911] - Replace AntClassLoader by RootLoader
    + [MSHARED-914] - Detailed message from failed script evaluation
    shouldn't be propagated
    + [MSHARED-917] - Remove dependency to
    plexus-component-annotations
    + [MSHARED-939] - Remove Apache Ivy from dependency
  * Task
    + [MSHARED-960] - document how to use Grapes in a Groovy script
* Mon Mar 21 2022 Fridrich Strba <fstrba@suse.com>
- Build with java source and target levels 8
* Tue May 11 2021 Fridrich Strba <fstrba@suse.com>
- Do not build against the legacy guava20 package
* Fri Mar 29 2019 Fridrich Strba <fstrba@suse.com>
- Initial packaging of maven-script-interpreter 1.2
- Generate and customize ant build.xml file
